API Reference — PBxplore 1.1 documentation

# API Reference

This page provides the documentation generated from the source files.

- Protein Blocks related data — `pbxplore.PB`
- Protein structure manipulation — `pbxplore.structure`
- Protrein Block assignation — `pbxplore.assignment`
- Input/Output in files — `pbxplore.io`
- Analyses – `pbxplore.analysis`
- Demonstration files — `pbxplore.demo`
- Functions directly accessible at the module level